<?php
namespace Neuron\Person\Controller\Api;

use Neuron\Generic\Result;
use Neuron\Application\Framework\Entity;
use Neuron\Person\Experiences;
use Neuron\Person\Experience as ExperienceModel;

class Experience extends \Neuron\Person\Controller {

    const CODE_FIELD_REQUIRED = 410;
    const CODE_SESSION_EXPIRED = 411;

    public function loadAction(){
        $result = new Result();
        $guid   = $this->getREST()->getGuid();
        if ($guid == "" || empty($guid)) {
            $result->code = self::CODE_FIELD_REQUIRED;
            $result->info = 'token is null';
            return $this->getREST()->getResponse($result);
        }

        $entity = Entity::get($this, $guid);
        $user = $entity->user();
        if (!$user->id) {
            $result->code = self::CODE_SESSION_EXPIRED;
            $result->info = 'Session Expired';
            return $this->getREST()->getResponse($result);
        }

        $userPerson = $this->getUserPerson($user);
        $person = $userPerson['person'];
        $personId = $person['person_id'];
        try {
            $Experiences = new Experiences(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $dataExperiences = $Experiences->load($personId, ExperienceModel\Storage::LISTBY_PERSON_TYPE);
            if($dataExperiences->code == 0){
                $result->data = $dataExperiences->data['list'];
            }else{
                $result->data = [];
            }
            $result->guid = $guid;
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading Experiences");
        }
		
		$requestPost = array(
			'guid' => $guid,
			'code' => '',
			'info' => '',
			'data' => ''
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $person ? $person : '';
		$logparam['description'] = 'Log proses api person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);

    }

    public function saveAction(){
        $result = new Result();
        $guid   = $this->getREST()->getGuid();
        $data   = $this->getREST()->getParameters();
        if ($guid == "" || empty($guid)) {
            $result->code = self::CODE_FIELD_REQUIRED;
            $result->info = 'token is null';
            return $this->getREST()->getResponse($result);
        }

        $entity = Entity::get($this, $guid);
        $user = $entity->user();
        if (!$user->id) {
            $result->code = self::CODE_SESSION_EXPIRED;
            $result->info = 'Session Expired';
            return $this->getREST()->getResponse($result);
        }

        $userPerson = $this->getUserPerson($user);
        $person = $userPerson['person'];
        $personId = $person['person_id'];
        $data['person_id'] = $personId;
        try {
            $Experience = new ExperienceModel(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $result = $Experience->create($data);
            $result->guid = $guid;
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed save Experience");
        }
		
		$requestPost = array(
			'guid' => $guid,
			'code' => '',
			'info' => '',
			'data' => ''
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON SAVE FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $person ? $person : '';
		$logparam['description'] = 'Log proses api person save family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);

    }

    public function deleteAction(){
        $result = new Result();
        $guid   = $this->getREST()->getGuid();
        $data   = $this->getREST()->getParameters();
        if ($guid == "" || empty($guid)) {
            $result->code = self::CODE_FIELD_REQUIRED;
            $result->info = 'token is null';
            return $this->getREST()->getResponse($result);
        }

        if ($data['experience_id'] == "" || empty($data['experience_id'])) {
            $result->code = self::CODE_FIELD_REQUIRED;
            $result->info = 'experience_id is null';
            return $this->getREST()->getResponse($result);
        }

        $entity = Entity::get($this, $guid);
        $user = $entity->user();
        if (!$user->id) {
            $result->code = self::CODE_SESSION_EXPIRED;
            $result->info = 'Session Expired';
            return $this->getREST()->getResponse($result);
        }
        try {
            $Experience = new ExperienceModel(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $result = $Experience->delete($data['experience_id']);
            $result->guid = $guid;
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed delete Experience");
        }
		
		$requestPost = array(
			'guid' => $guid,
			'code' => '',
			'info' => '',
			'data' => ''
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON SAVE FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $person ? $person : '';
		$logparam['description'] = 'Log proses api person save family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);

    }

}
