<?php

namespace Neuron\Person\Map\Storage;

use Zend\Db\Adapter\Adapter;
use Zend\Db\Sql\Where;
use Zend\Db\Sql\Predicate\Expression;

use Neuron\Person\Map\Storage;


class Mysql extends \Neuron\Db\Storage implements Skeleton {

	public function save(\Neuron\Person\Map $map, $update = false) {
		if ($update == true) {
			
			$update = $this->update()
				->table($this->_tables['person_user_map'])
				->set($this->__($map->pull()))
				->where($this->__(array('user_map_id' => $map->user_map_id)));

			// echo str_replace('"','',$update->getSqlString()).'<br />';
			if ($this->execute($update)) {
					return $map->user_map_id;
			}
			
		} else {
			$insert = $this->insert()
			->into($this->_tables['person_user_map'])
			->values($this->__($map->pull()));
			$save = $this->execute($insert);
			if ($save) {
					$map->user_map_id = $save;
					return $map->user_map_id;
			}
		}

		return false;
	}
	
	public function load($id, $mode = Storage::LOADBY_ID) {
		$select = $this->select()
			->from($this->_tables['person_user_map']);

		switch ($mode){
			case Storage::LOADBY_ID :
				$select->where($this->__(array('user_map_id' => $id)));
				break;
			case Storage::LOADBY_PERSON_ID:
				$select->where($this->__(array('person_id' => $id)));
				break;
			case Storage::LOADBY_USER_ID:
				$select->where(array(
					$this->_('user_id') => $id
				));
			break;
		}
		// echo str_replace('"','',$select->getSqlString());die();
		return $this->fetchRow($select);
	}

	public function remove($id) {
		//delete detail
		$deleteDetail = $this->delete()
						->from($this->_tables['person_detail'])
						->where(array('person_id'=> $id));
		$this->execute($deleteDetail);
		//delete education
		$deleteEducation = $this->delete()
						->from($this->_tables['person_education'])
						->where(array('person_id'=> $id));
		$this->execute($deleteEducation);
		//delete experience
		$deleteExperience = $this->delete()
						->from($this->_tables['person_experiences'])
						->where(array('person_id'=> $id));
		$this->execute($deleteExperience);
		//delete family
		$deleteFamily = $this->delete()
						->from($this->_tables['person_family'])
						->where(array('person_id'=> $id));
		$this->execute($deleteFamily);
		//delete medical
		$deleteMedical = $this->delete()
						->from($this->_tables['person_medical'])
						->where(array('person_id'=> $id));
		$this->execute($deleteMedical);
		$delete = $this->delete()
						->from($this->_tables['person'])
						->where(array('id' => $id));
		// echo str_replace('"','', $delete->getSqlString())."<br />"; exit;				
		return $this->execute($delete);
	}

	public function loadList($id = null, $mode = Storage::LIST_ALL,$params = array()){
        $select         = $this->select();
        $select->from(array(
            'um' => $this->_tables['person_user_map']
		));
		
        if(isset($params['draw'])){
            $select->limit(intval($params['length']));
            $select->offset(intval($params['start']));

            $orderColumn    = $params['columns'][$params['order'][0]['column']]['data'];
            $dir            = $params['order'][0]['dir'];

			$select->order($orderColumn.' '.$dir);

        }

        try{
			$result = new \stdClass;
            $data   = $this->fetchAll($select);
            if($data){
                $selectC = $select;
                $selectC->reset('limit')->reset('offset');
                $selectC->columns(array('countTotal' => new Expression('COUNT(*)')));
                $countTotal = $this->fetchRow($selectC)['countTotal'];
    
                $result->rows   = $data;
                $result->countTotal = $countTotal;
            }else{
                $result->rows   = array();
                $result->countTotal = 0;
            }

            return $result;
        }catch(\Exception $ex){
            return false;
            error_log('Error ::'.$ex->getMessage());
        }
    }


}